@@ -30,9 +30,7 @@ class Converter(object):
         """ Obtain HIVE/MVESTS ratio
         """
         info = self.hived.get_dynamic_global_properties()
-        print(info)
-        import sys
-        sys.exit()
+
         return (Amount(info["total_vesting_fund_steem"]).amount /
                 (Amount(info["total_vesting_shares"]).amount / 1e6))
 
